@@ -1,4 +1,4 @@
-/* anonmap.c - Tests wether code can be executed in anonymous mappings
+/* anonmap.c - Tests whether code can be executed in anonymous mappings
  *
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
@@ -10,10 +10,11 @@
 #include <unistd.h>
 #include <sys/mman.h>
 #include "body.h"
+#include "shellcode.h"
 
-char *testname = "Executable anonymous mapping             ";
+const char testname[] = "Executable anonymous mapping             ";
 
-#ifdef __OpenBSD__
+#ifndef MAP_ANONYMOUS
 #define MAP_ANONYMOUS MAP_ANON
 #endif
 
@@ -23,13 +24,12 @@ void doit( void )
 	fptr func;
 
 	buf = mmap(NULL, 4096, PROT_READ|PROT_WRITE, MAP_PRIVATE|MAP_ANONYMOUS, -1, 0);
-	if( buf == NULL ) {
+	if( buf == MAP_FAILED ) {
 		fprintf( stderr, "mmap() returned NULL\n" );
 		exit( 1 );
 	}
 
-	/* Put a RETN instruction in the buffer */
-	*buf = '\xc3';
+	copy_shellcode(buf, SHELLCODE_RETURN);
 
 	/* Convert the pointer to a function pointer */
 	func = (fptr)buf;
@@ -40,4 +40,3 @@ void doit( void )
 	/* It worked when the function returns */
 	itworked();
 }
-
