@@ -15,13 +15,10 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <pthread.h>
-
-#ifndef PAGESIZE
-#define PAGESIZE	(4096)
-#endif /* PAGESIZE */
+#include <unistd.h>
 
 extern int doit( void );
-extern char *testname;
+extern const char testname[];
 
 static void *test_thread(void *p)
 {
@@ -96,12 +93,13 @@ int do_mprotect( const void *addr, size_t len, int prot )
 {
 	void *ptr;
 	int retval;
+	long PAGESIZE = sysconf(_SC_PAGESIZE);
 
 	/* Allign to a multiple of PAGESIZE, assumed to be a power of two */
 	ptr = (char *)(((unsigned long) addr) & ~(PAGESIZE-1));
 
 	retval = mprotect( ptr, len, prot );
-	if( retval != 0 && errno == EINVAL ) {
+	if( retval != 0 && (errno == EINVAL)) {
 		perror( "could not mprotect():" );
 		exit( 1 );
 	}
