@@ -1,4 +1,4 @@
-/* execbss.c - Tests wether code in the .bss segment can be executed
+/* execbss.c - Tests whether code in the .bss segment can be executed
  *
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
@@ -8,17 +8,17 @@
 #include <string.h>
 #include <stdlib.h>
 #include "body.h"
+#include "shellcode.h"
 
-char *testname = "Executable bss                           ";
+const char testname[] = "Executable bss                           ";
 
-char buf;
+char buf[MAX_SHELLCODE_LEN];
 
 void doit( void )
 {
 	fptr func;
 
-	/* Put a RETN instruction in the buffer */
-	buf = '\xc3';
+	copy_shellcode(buf, SHELLCODE_RETURN);
 
 	/* Convert the pointer to a function pointer */
 	func = (fptr)&buf;
@@ -29,4 +29,3 @@ void doit( void )
 	/* It worked when the function returns */
 	itworked();
 }
-
