@@ -1,4 +1,4 @@
-/* execdata.c - Tests wether code in the .data segment can be executed
+/* execdata.c - Tests whether code in the .data segment can be executed
  *
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
@@ -8,15 +8,18 @@
 #include <string.h>
 #include <stdlib.h>
 #include "body.h"
+#include "shellcode.h"
 
-char *testname = "Executable data                          ";
+const char testname[] = "Executable data                          ";
 
-char buf = '\xc3';	/* RETN instruction */
+char buf[MAX_SHELLCODE_LEN] = SHELLCODE_RETURN_ARRAY;
 
 void doit( void )
 {
 	fptr func;
 
+	copy_shellcode(buf, SHELLCODE_RETURN);
+
 	/* Convert the pointer to a function pointer */
 	func = (fptr)&buf;
 
@@ -26,4 +29,3 @@ void doit( void )
 	/* It worked when the function returns */
 	itworked();
 }
-
