@@ -1,4 +1,4 @@
-/* execstack.c - Tests wether code on the stack can be executed
+/* execstack.c - Tests whether code on the stack can be executed
  *
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
@@ -8,16 +8,16 @@
 #include <string.h>
 #include <stdlib.h>
 #include "body.h"
+#include "shellcode.h"
 
-char *testname = "Executable stack                         ";
+const char testname[] = "Executable stack                         ";
 
 void doit( void )
 {
 	char buf[8192];
 	fptr func;
 
-	/* Put a RETN instruction in the buffer */
-	buf[0] = '\xc3';
+	copy_shellcode(buf, SHELLCODE_RETURN);
 
 	/* Convert the pointer to a function pointer */
 	func = (fptr)buf;
@@ -28,4 +28,3 @@ void doit( void )
 	/* It worked when the function returns */
 	itworked();
 }
-
