@@ -1,4 +1,4 @@
-/* mprotanon.c - Tests wether code can be executed in anonymous mappings
+/* mprotanon.c - Tests whether code can be executed in anonymous mappings
  *               after trying to use mprotect() to make it executable.
  *
  * Copyright (c)2003,2004 by Peter Busser <peter@adamantix.org>
@@ -11,12 +11,13 @@
 #include <unistd.h>
 #include <sys/mman.h>
 #include "body.h"
+#include "shellcode.h"
 
-#ifdef __OpenBSD__
+#ifndef MAP_ANONYMOUS
 #define MAP_ANONYMOUS MAP_ANON
 #endif
 
-char *testname = "Executable anonymous mapping (mprotect)  ";
+const char testname[] = "Executable anonymous mapping (mprotect)  ";
 
 void doit( void )
 {
@@ -24,13 +25,12 @@ void doit( void )
 	fptr func;
 
 	buf = mmap(NULL, 4096, PROT_READ|PROT_WRITE, MAP_PRIVATE|MAP_ANONYMOUS, -1, 0);
-	if( buf == NULL ) {
+	if( buf == MAP_FAILED ) {
 		fprintf( stderr, "mmap() returned NULL\n" );
 		exit( 1 );
 	}
 
-	/* Put a RETN instruction in the buffer */
-	*buf = '\xc3';
+	copy_shellcode(buf, SHELLCODE_RETURN);
 
 	/* Convert the pointer to a function pointer */
 	func = (fptr)buf;
@@ -54,7 +54,8 @@ void doit( void )
 	 * But then, it is of course easier to simply disable this mprotect()
 	 * call than to fix your kernel and userland.
 	 */
-	do_mprotect( buf, 1, PROT_EXEC );
+	/* Due to a FreeBSD bug PROT_READ is required */
+	do_mprotect( buf, 4096, PROT_READ|PROT_EXEC );
 
 	/* Call the code in the buffer */
 	func();
@@ -62,4 +63,3 @@ void doit( void )
 	/* It worked when the function returns */
 	itworked();
 }
-
