@@ -1,4 +1,4 @@
-/* mprotbss.c - Tests wether code in the .bss segment can be executed after
+/* mprotbss.c - Tests whether code in the .bss segment can be executed after
  *              trying to use mprotect() to make it executable
  *
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
@@ -10,30 +10,30 @@
 #include <stdlib.h>
 #include <sys/mman.h>
 #include "body.h"
+#include "shellcode.h"
 
-char *testname = "Executable bss (mprotect)                ";
+const char testname[] = "Executable bss (mprotect)                ";
 
-char buf;
+char buf[MAX_SHELLCODE_LEN];
 
 void doit( void )
 {
 	fptr func;
 
-	/* Put a RETN instruction in the buffer */
-	buf = '\xc3';
+	copy_shellcode(buf, SHELLCODE_RETURN);
 
 	/* Convert the pointer to a function pointer */
 	func = (fptr)&buf;
 
 	/* Try to make the bss executable first by using mprotect */
-	do_mprotect( &buf, 1, PROT_EXEC );
+	/* Due to a FreeBSD bug PROT_READ is required */
+	do_mprotect( &buf, sizeof(buf), PROT_READ|PROT_EXEC );
 
 	/* Call the code in the buffer */
 	func();
 
-	do_mprotect( &buf, 1, PROT_READ|PROT_WRITE );
+	do_mprotect( &buf, sizeof(buf), PROT_READ|PROT_WRITE );
 
 	/* It worked when the function returns */
 	itworked();
 }
-
