@@ -1,4 +1,4 @@
-/* mprotheap.c - Tests wether code on the heap can be executed after trying to
+/* mprotheap.c - Tests whether code on the heap can be executed after trying to
  *               use mprotect() to make it executable.
  *
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
@@ -10,25 +10,26 @@
 #include <stdlib.h>
 #include <sys/mman.h>
 #include "body.h"
+#include "shellcode.h"
 
-char *testname = "Executable heap (mprotect)               ";
+const char testname[] = "Executable heap (mprotect)               ";
 
 void doit( void )
 {
 	char *buf;
 	fptr func;
 
-	buf = malloc( 1 );
+	buf = malloc( MAX_SHELLCODE_LEN );
 	if( buf == NULL ) {
 		fprintf( stderr, "Out of memory\n" );
 		exit( 1 );
 	}
 
-	/* Put a RETN instruction in the buffer */
-	*buf = '\xc3';
+	copy_shellcode(buf, SHELLCODE_RETURN);
 
 	/* Try to make the buffer executable by using mprotect() */
-	do_mprotect( buf, 1, PROT_EXEC );
+	/* Due to a FreeBSD bug PROT_READ is required */
+	do_mprotect( buf, SIZE_OF_SHELLCODE_RETURN, PROT_READ|PROT_EXEC );
 
 	/* Convert the pointer to a function pointer */
 	func = (fptr)buf;
@@ -36,9 +37,8 @@ void doit( void )
 	/* Call the code in the buffer */
 	func();
 
-	do_mprotect( buf, 1, PROT_READ|PROT_WRITE );
+	do_mprotect( buf, MAX_SHELLCODE_LEN, PROT_READ|PROT_WRITE );
 
 	/* It worked when the function returns */
 	itworked();
 }
-
