@@ -1,4 +1,4 @@
-/* mprotstack.c - Tests wether code on the stack can be executed after trying
+/* mprotstack.c - Tests whether code on the stack can be executed after trying
  *                to make it executable by using mprotect().
  *
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
@@ -10,22 +10,22 @@
 #include <stdlib.h>
 #include <sys/mman.h>
 #include "body.h"
+#include "shellcode.h"
 
-char *testname = "Executable stack (mprotect)              ";
+const char testname[] = "Executable stack (mprotect)              ";
 
 void doit( void )
 {
-	char buf;
+	char buf[MAX_SHELLCODE_LEN];
 	fptr func;
 
-	/* Put a RETN instruction in the buffer */
-	buf = '\xc3';
+	copy_shellcode(buf, SHELLCODE_RETURN);
 
 	/* Convert the pointer to a function pointer */
 	func = (fptr)&buf;
 
 	/* Try to make the stack executable first */
-	do_mprotect( &buf, 1, PROT_READ|PROT_WRITE|PROT_EXEC );
+	do_mprotect( &buf, sizeof(buf), PROT_READ|PROT_WRITE|PROT_EXEC );
 
 	/* Call the code in the buffer */
 	func();
@@ -33,4 +33,3 @@ void doit( void )
 	/* It worked when the function returns */
 	itworked();
 }
-
