@@ -1,4 +1,4 @@
-/* rettofunc2.c - Tests wether return to function exploits using memcpy() work
+/* rettofunc2.c - Tests whether return to function exploits using memcpy() work
  *
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
@@ -8,7 +8,7 @@
 #include <string.h>
 #include "body.h"
 
-char *testname = "Return to function (memcpy, RANDEXEC)    ";
+const char testname[] = "Return to function (memcpy, PIE)         ";
 
 fptr overflow[32] = {
 	itworked, itworked, itworked, itworked, itworked, itworked, itworked, itworked,
@@ -23,4 +23,3 @@ void doit( void )
 
 	memcpy( buf, overflow, sizeof( overflow ) );
 }
-
