@@ -3,10 +3,11 @@
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
  */
+#include "shellcode.h"
 
-char bufbss;
+char shbss[4096];
 
-char bufdata = '\xc3';
+char shdata[4096] = SHELLCODE_RETURN_ARRAY;
 
 /* A function which does nothing, it only exists so it can be referenced */
 int shlibtest( void )
