@@ -4,9 +4,11 @@
  * This file has been released under the GNU Public Licence version 2 or later
  */
 
-char bufbss2;
+#include "shellcode.h"
 
-char bufdata2 = '\xc3';
+char shbss2[4096];
+
+char shdata2[4096] = SHELLCODE_RETURN_ARRAY;
 
 /* A function which does nothing, it only exists so it can be referenced */
 int shlibtest2( void )
